#!/usr/bin/env python
# -*- coding:utf-8 -*-
__author__ = 'bee'

from django.conf.urls import include, url
from . import views

urlpatterns = [
    url(r'^test$', views.test, name='test'),
    url(r'^$', views.CoinTypeList.as_view(), name='index'),
    # =======发金币类型========
    url(r'^type/list$', views.CoinTypeList.as_view(), name='coin_type_list'),
    # url(r'^message/detail/(?P<pk>[0-9]+)$', views.CoinTypeDetail.as_view(), name='coin_type_detail'),
    url(r'^type/add/$', views.CoinTypeCreate.as_view(), name='coin_type_add'),
    url(r'^type/update/(?P<pk>[0-9]+)/$', views.CoinTypeUpdate.as_view(), name='coin_type_update'),
    url(r'^type/delete/(?P<pk>[0-9]+)/$', views.CoinTypeDelete.as_view(), name='coin_type_delete'),
    # =======发送记录========
    url(r'^user/record/list/(?P<user_id>[0-9]+)/$', views.UserRecordList.as_view(), name='user_record_list'),
    # url(r'^user/record/click$', views.UserRecordClick.as_view(), name='user_record_click'),

]


# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import models
from django.core.urlresolvers import reverse
from django.conf import settings
from django.contrib.auth.models import User


# Create your models here.
def get_user_table():
    if settings.MESSAGE_USER_TABLE in ["", None]:
        user_table = User
    else:
        user_table = settings.MESSAGE_USER_TABLE
    return user_table

# 获取自定义user的自定义name
def get_user_name(user):
    try:
        return getattr(user, settings.COIN_USER_NAME_FIELD)
    except:
        return None

class CoinType(models.Model):
    name = models.CharField(max_length=180, verbose_name='名称类型')
    coin = models.IntegerField(verbose_name="数量")
    info = models.CharField(max_length=180, null=True, blank=True, verbose_name='说明')
    identity=models.CharField(max_length=180,null=True,verbose_name='标识符',unique=True)


    class Meta:
        app_label = 'bee_django_coin'
        db_table = 'bee_django_coin_type'
        ordering = ["id"]

    def __unicode__(self):
        return ("CoinType->name:" + self.name)

    def get_absolute_url(self):
        return reverse('bee_django_coin:coin_type_list')


# 缦币
class UserCoinRecord(models.Model):
    user = models.ForeignKey(get_user_table(), related_name='coin_user')
    coin = models.IntegerField(verbose_name='数量')
    created_by = models.ForeignKey(get_user_table(), related_name="created_by_user", null=True)
    reason = models.CharField(max_length=180, verbose_name='原因', null=True, blank=True)
    created_at = models.DateTimeField(auto_now_add=True)
    coin_type = models.ForeignKey('bee_django_coin.CoinType', null=True, on_delete=models.SET_NULL)

    class Meta:
        app_label = 'bee_django_coin'
        db_table = 'bee_django_coin_record'
        ordering = ["-created_at"]

    def __unicode__(self):
        return ("UserCoinRecord->reason:" + self.reason)

    def get_absolute_url(self):
        return reverse('bee_django_coin:user_coin_record')

    def get_created_by_user_name(self):
        if self.created_by:
            return get_user_name(self.created_by)
        else:
            return settings.COIN_DEFAULT_NAME



#!/usr/bin/env python
# -*- coding:utf-8 -*-
__author__ = 'bee'

from django import forms
from .models import CoinType


# ===== course contract======
class CoinTypeForm(forms.ModelForm):
    class Meta:
        model = CoinType
        fields = ['name',"identity", "coin", "info"]


#!/usr/bin/env python
# -*- coding:utf-8 -*-
__author__ = 'zhangyue'

from django import template
from bee_django_message.exports import filter_local_datetime


register = template.Library()


# 本地化时间
@register.filter
def local_datetime(_datetime):
    return filter_local_datetime(_datetime)


# 求两个值的差的绝对值
@register.filter
def get_difference_abs(a, b):
    return abs(a - b)



#!/usr/bin/env python
# -*- coding:utf-8 -*-
__author__ = 'bee'

from .utils import get_login_user, get_coin_type
from .models import CoinType, UserCoinRecord


# django前台显示本地时间
def filter_local_datetime(_datetime):
    return _datetime


def get_user(request):
    return get_login_user(request)


# 操作消息记录，返回结果
def add_coin_record(to_user, reason=None, identity=None, coin=None, created_by=None):
    try:
        record = UserCoinRecord()
        record.user = to_user
        coin_type = get_coin_type(identity)
        record.coin_type = coin_type
        if coin:
            record.coin = coin
        elif coin_type:
            record.coin = coin_type.coin
        record.reason = reason
        record.created_by = created_by
        record.save()
        return record.coin
    except Exception as e:
        print('bee_django_coin->add_coin_record->error:' + e.__str__())
        return None



#!/usr/bin/env python
# -*- coding:utf-8 -*-
from __future__ import unicode_literals

import json
from django.shortcuts import render
from django.core.urlresolvers import reverse_lazy
from django.utils.decorators import method_decorator
from .decorators import cls_decorator, func_decorator
from django.views.generic import ListView, DetailView, TemplateView
from django.db.models import Q, Sum, Count
from django.views.generic.edit import CreateView, UpdateView, DeleteView
from .models import CoinType, UserCoinRecord
from .forms import CoinTypeForm

from .exports import get_user
from .utils import get_user_model, get_user_name, get_default_name


# Create your views here.
# =======course=======
def test(request):
    from exports import add_coin_record
    from django.contrib.auth.models import User
    to_user = User.objects.all().first()
    res = add_coin_record(to_user=to_user, coin_type_id=2,reason='test',created_by=to_user)
    print(res)
    return


@method_decorator(cls_decorator(cls_name='CoinTypeList'), name='dispatch')
class CoinTypeList(ListView):
    template_name = 'bee_django_coin/coin_type/coin_type_list.html'
    context_object_name = 'coin_type_list'
    paginate_by = 20
    queryset = CoinType.objects.all()


# @method_decorator(cls_decorator(cls_name='MessageDetail'), name='dispatch')
# class CoinTypeDetail(DetailView):
#     model = Message
#     template_name = 'bee_django_message/message/message_detail.html'
#     context_object_name = 'message'


@method_decorator(cls_decorator(cls_name='CoinTypeCreate'), name='dispatch')
class CoinTypeCreate(CreateView):
    model = CoinType
    form_class = CoinTypeForm
    template_name = 'bee_django_coin/coin_type/coin_type_form.html'


@method_decorator(cls_decorator(cls_name='CoinTypeUpdate'), name='dispatch')
class CoinTypeUpdate(UpdateView):
    model = CoinType
    form_class = CoinTypeForm
    template_name = 'bee_django_coin/coin_type/coin_type_form.html'


@method_decorator(cls_decorator(cls_name='CoinTypeDelete'), name='dispatch')
class CoinTypeDelete(DeleteView):
    model = CoinType
    success_url = reverse_lazy('bee_django_coin:coin_type_list')

    def get(self, request, *args, **kwargs):
        return self.http_method_not_allowed(request, *args, **kwargs)


# 发金币记录
@method_decorator(cls_decorator(cls_name='UserRecordList'), name='dispatch')
class UserRecordList(ListView):
    template_name = 'bee_django_coin/record/user_record_list.html'
    context_object_name = 'record_list'
    paginate_by = 20
    queryset = None

    def get_user(self):
        user_id = self.kwargs["user_id"]
        try:
            user_table = get_user_model()
            user = user_table.objects.get(id=user_id)
        except:
            user = None
        return user

    def get_queryset(self):
        self.queryset = UserCoinRecord.objects.filter(user=self.get_user())
        print(self.queryset)
        return self.queryset

    def get_context_data(self, **kwargs):
        user = self.get_user()
        context = super(UserRecordList, self).get_context_data(**kwargs)
        context['user_name'] = get_user_name(user)
        context['default_name'] = get_default_name
        return context

#
# #
# # @method_decorator(cls_decorator(cls_name='RecordDetail'), name='dispatch')
# # class RecordDetail(DetailView):
# #     model = SendRecord
# #     template_name = 'bee_django_message/message/message_detail.html'
# #     context_object_name = 'record'
#
#
# @method_decorator(cls_decorator(cls_name='UserRecordClick'), name='dispatch')
# class UserRecordClick(TemplateView):
#     def post(self, request, *args, **kwargs):
#         record_id = request.POST.get("record_id")
#         record = SendRecord.objects.get(id=record_id)
#         record.is_view = True
#         record.save()
#         return JSONResponse(json.dumps({"url": record.url}, ensure_ascii=False))



# -*- coding: utf-8 -*-
# Generated by Django 1.11 on 2017-12-27 07:43
from __future__ import unicode_literals

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.CreateModel(
            name='CoinType',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=180, verbose_name='\u540d\u79f0\u7c7b\u578b')),
                ('coin', models.IntegerField(verbose_name='\u6570\u91cf')),
                ('info', models.CharField(blank=True, max_length=180, null=True, verbose_name='\u8bf4\u660e')),
            ],
            options={
                'ordering': ['id'],
                'db_table': 'bee_django_coin_type',
            },
        ),
        migrations.CreateModel(
            name='UserCoinRecord',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('coin', models.IntegerField(verbose_name='\u6570\u91cf')),
                ('reason', models.CharField(blank=True, max_length=180, null=True, verbose_name='\u539f\u56e0')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('coin_type', models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, to='bee_django_coin.CoinType')),
                ('created_by', models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='created_by_user', to=settings.AUTH_USER_MODEL)),
                ('user', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='coin_user', to=settings.AUTH_USER_MODEL)),
            ],
            options={
                'ordering': ['-created_at'],
                'db_table': 'bee_django_coin_record',
            },
        ),
    ]
